@@ -81,39 +81,9 @@ JAGS_bridgesampling <- function(fit, log_posterior, data = NULL, prior_list = NU
   check_list(formula_data_list, "formula_data_list", check_names = names(formula_list), allow_other = FALSE, all_objects = TRUE, allow_NULL = is.null(formula_list))
   check_list(formula_prior_list, "formula_prior_list", check_names = names(formula_list), allow_other = FALSE, all_objects = TRUE, allow_NULL = is.null(formula_list))
 
-  ### check the input and split it on posterior and data
-  if(inherits(fit, "runjags")){
-
-    # get posterior and merge chains
-    posterior <- suppressWarnings(coda::as.mcmc(fit))
-
-  }else if(is.list(fit) & all(sapply(fit, inherits, what = "mcarray"))){
-
-    # rjags model with rjags::jags.samples
-    # merge chains
-    posterior <- do.call(cbind, lapply(names(fit), function(par){
-      if(dim(fit[[par]])[1] > 1){
-        samples <- do.call(rbind, lapply(1:(dim(fit[[par]]))[3],  function(chain)t(fit[[par]][,,chain])))
-        colnames(samples) <- paste0(attr(fit[[par]], "varname"), "[",1:ncol(samples),"]")
-      }else{
-        samples <- matrix(do.call(c, lapply(1:(dim(fit[[par]]))[3],  function(chain)fit[[par]][,,chain])), ncol = 1)
-        colnames(samples) <- attr(fit[[par]], "varname")
-      }
-      return(samples)
-    }))
-
-  }else if(inherits(fit, "mcmc.list")){
-
-    # rjags model with rjags::coda.samples
-    # merge chains
-    posterior <- do.call(rbind, fit)
-
-  }else{
-
-    stop("the method is not implemented for this output")
-
-  }
 
+  # extract the posterior distribution
+  posterior <- .fit_to_posterior(fit)
 
   ### prepare formula objects summary
   if(!is.null(formula_list)){
@@ -154,7 +124,7 @@ JAGS_bridgesampling <- function(fit, log_posterior, data = NULL, prior_list = NU
       parameters <- c(parameters, JAGS_marglik_parameters(samples.row, prior_list))
     }
     if(!is.null(formula_prior_list)){
-      parameters <- c(parameters, JAGS_marglik_parameters_formula(samples.row, formula_data_list, formula_prior_list))
+      parameters <- c(parameters, JAGS_marglik_parameters_formula(samples.row, formula_data_list, formula_prior_list, parameters))
     }
     if(!is.null(add_parameters)){
       parameters <- c(parameters, samples.row[add_parameters])
@@ -168,7 +138,7 @@ JAGS_bridgesampling <- function(fit, log_posterior, data = NULL, prior_list = NU
     if(!is.null(formula_prior_list)){
       marglik <- marglik + JAGS_marglik_priors_formula(samples.row, formula_prior_list)
     }
-    marglik   <- marglik + log_posterior(parameters, data, ...)
+    marglik   <- marglik + log_posterior(parameters = parameters, data = data, ...)
 
     return(marglik)
   }
@@ -200,7 +170,43 @@ JAGS_bridgesampling <- function(fit, log_posterior, data = NULL, prior_list = NU
   return(marglik)
 }
 
+.fit_to_posterior <- function(fit){
 
+  ### check the input and split it on posterior and data
+  if(inherits(fit, "runjags")){
+
+    # get posterior and merge chains
+    posterior <- suppressWarnings(coda::as.mcmc(fit))
+
+  }else if(is.list(fit) & all(sapply(fit, inherits, what = "mcarray"))){
+
+    # rjags model with rjags::jags.samples
+    # merge chains
+    posterior <- do.call(cbind, lapply(names(fit), function(par){
+      if(dim(fit[[par]])[1] > 1){
+        samples <- do.call(rbind, lapply(1:(dim(fit[[par]]))[3],  function(chain)t(fit[[par]][,,chain])))
+        colnames(samples) <- paste0(attr(fit[[par]], "varname"), "[",1:ncol(samples),"]")
+      }else{
+        samples <- matrix(do.call(c, lapply(1:(dim(fit[[par]]))[3],  function(chain)fit[[par]][,,chain])), ncol = 1)
+        colnames(samples) <- attr(fit[[par]], "varname")
+      }
+      return(samples)
+    }))
+
+  }else if(inherits(fit, "mcmc.list")){
+
+    # rjags model with rjags::coda.samples
+    # merge chains
+    posterior <- do.call(rbind, fit)
+
+  }else{
+
+    stop("the method is not implemented for this output")
+
+  }
+
+  return(posterior)
+}
 
 #' @title Prepare 'JAGS' posterior for 'bridgesampling'
 #'
@@ -378,7 +384,7 @@ JAGS_bridgesampling_posterior <- function(posterior, prior_list, add_parameters
   if(!is.character(parameter_name) | length(parameter_name) != 1)
     stop("'parameter_name' must be a character vector of length 1.")
 
-  if(is.prior.dummy(prior)){
+  if(is.prior.point(prior) | is.prior.dummy(prior)){
 
     if((attr(prior, "levels") - 1) == 1){
 
@@ -575,7 +581,7 @@ JAGS_marglik_priors                <- function(samples, prior_list){
   if(!is.character(parameter_name) | length(parameter_name) != 1)
     stop("'parameter_name' must be a character vector of length 1.")
 
-  if(is.prior.dummy(prior)){
+  if(is.prior.point(prior) | is.prior.dummy(prior)){
 
     if((attr(prior, "levels") - 1) == 1){
 
@@ -656,6 +662,8 @@ JAGS_marglik_priors_formula <- function(samples, formula_prior_list){
 #'
 #' @param samples samples provided by bridgesampling
 #' function
+#' @param prior_list_parameters named list of prior distributions on model parameters
+#' (not specified within the formula but that might scale the formula parameters)
 #'
 #' @return \code{JAGS_marglik_parameters} returns a named list
 #' of (transformed) posterior samples.
@@ -758,7 +766,7 @@ JAGS_marglik_parameters                <- function(samples, prior_list){
     stop("'parameter_name' must be a character vector of length 1.")
 
 
-  if(is.prior.dummy(prior)){
+  if(is.prior.point(prior) | is.prior.dummy(prior)){
 
     if((attr(prior, "levels") - 1) == 1){
 
@@ -832,7 +840,7 @@ JAGS_marglik_parameters                <- function(samples, prior_list){
 }
 
 #' @rdname JAGS_marglik_parameters
-JAGS_marglik_parameters_formula      <- function(samples, formula_data_list, formula_prior_list){
+JAGS_marglik_parameters_formula      <- function(samples, formula_data_list, formula_prior_list, prior_list_parameters){
 
   # return empty list in case that no prior was specified
   if(length(formula_prior_list) == 0){
@@ -842,13 +850,13 @@ JAGS_marglik_parameters_formula      <- function(samples, formula_data_list, for
   parameters <- list()
 
   for(parameter in names(formula_prior_list)){
-    parameters[[parameter]] <- .JAGS_marglik_parameters_formula_get(samples, parameter, formula_data_list[[parameter]], formula_prior_list[[parameter]])
+    parameters[[parameter]] <- .JAGS_marglik_parameters_formula_get(samples, parameter, formula_data_list[[parameter]], formula_prior_list[[parameter]], prior_list_parameters)
   }
 
   return(parameters)
 }
 
-.JAGS_marglik_parameters_formula_get <- function(samples, parameter, formula_data_list, formula_prior_list){
+.JAGS_marglik_parameters_formula_get <- function(samples, parameter, formula_data_list, formula_prior_list, prior_list_parameters){
 
   formula_terms            <- names(formula_prior_list)
   names(formula_data_list) <- gsub("_data", "", names(formula_data_list))
@@ -865,19 +873,35 @@ JAGS_marglik_parameters_formula      <- function(samples, formula_data_list, for
   if(length(remaining_terms) > 0){
     for(term in remaining_terms){
 
-      if(is.prior.factor(formula_prior_list[[term]])){
+      # check for scaling factors
+      if(!is.null(attr(formula_prior_list[[term]], "multiply_by"))){
+        if(is.numeric(attr(formula_prior_list[[term]], "multiply_by"))){
+          multiply_by <- attr(formula_prior_list[[term]], "multiply_by")
+        }else{
+          multiply_by <- prior_list_parameters[[attr(formula_prior_list[[term]], "multiply_by")]]
+        }
+      }else{
+        multiply_by <- 1
+      }
+
+
+      if(is.prior.point(formula_prior_list[[term]])){
+
+        output <- output + multiply_by * formula_prior_list[[term]][["parameters"]][["location"]] * formula_data_list[[term]]
+
+      }else if(is.prior.factor(formula_prior_list[[term]])){
 
         levels <- attr(formula_prior_list[[term]], "levels")
         if((levels-1) == 1){
-          output <- output + samples[[term]] * formula_data_list[[term]]
+          output <- output + multiply_by * samples[[term]] * formula_data_list[[term]]
         }else{
-          output <- output + formula_data_list[[term]] %*% samples[paste0(term,"[", 1:(levels-1), "]")]
+          output <- output + multiply_by * formula_data_list[[term]] %*% samples[paste0(term,"[", 1:(levels-1), "]")]
         }
 
 
       }else if(is.prior.simple(formula_prior_list[[term]])){
 
-        output <- output + samples[[term]] * formula_data_list[[term]]
+        output <- output + multiply_by * samples[[term]] * formula_data_list[[term]]
 
       }
 
